@@ -1,7 +1,7 @@
 package AnyEvent::CallbackStack;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use utf8;
 use feature 'say';
@@ -14,7 +14,8 @@ use constant DEBUG => $ENV{ANYEVENT_CALLBACKSTACK_DEBUG};
 my @cbq;
 my $step;
 
-=encoding utf-8
+=encoding utf8
+
 =head1 NAME
 
 AnyEvent::CallbackStack - Convert nested callback into easy-to-read-write-and-maintain serial/procedural coding style by using Callback Stack.
@@ -23,31 +24,35 @@ AnyEvent::CallbackStack - Convert nested callback into easy-to-read-write-and-ma
 
 Use L<AnyEvent::CallbackStack> with the following style.
 
-    use feature 'say';
-    use AnyEvent::CallbackStack;
+	use feature 'say';
+	use AnyEvent::CallbackStack;
+	
+	my $cs = AnyEvent::CallbackStack->new();
+	$cs->start( %foo );
+	$cs->add( sub {
+		do_something;
+		$cs->next( $bar, $yohoo );
+	});
+	
+	$cv = $cs->last;
+	return $cv;
 
-    my $cs = AnyEvent::CallbackStack->new();
-    $cs->start( %foo );
-    $cs->add( sub {
-	    do_something;
-	    $cs->next( $bar, $yohoo );
-    });
-    
-    $cv = $cs->last;
-    return $cv;
-    
-    # or
-    
-    http_get http://BlueT.org => sub { $cs->start($_[0]) };
-    $cs->add( sub { say $_[0]->recv } );
-    
-    # or
-    
-    $cs->add( sub { say 'I got the ball'; $cs->next( $_[0]->recv ); } )
-    print 'Your name please?: ';
-    chomp(my $in = <STDIN>);
-    $cs->start($in);
-    $cs->add( sub { say "Lucky you, $_[0]->recv" } );
+# or
+
+	http_get http://BlueT.org => sub { $cs->start($_[0]) };
+	$cs->add( sub { say $_[0]->recv } );
+
+# or
+
+	$cs->add( sub { say 'I got the ball'; $cs->next( $_[0]->recv ); } )
+	print 'Your name please?: ';
+	chomp(my $in = <STDIN>);
+	$cs->start($in);
+	$cs->add( sub { say "Lucky you, $_[0]->recv" } );
+
+# or
+
+	my $cs = AE::CS;
 
 =head1 METHODS
 
@@ -61,16 +66,12 @@ No paramater needed.
 
 sub new {
 	my $class = shift;
-	
 	my $self  = {};
-	
-	my $cv = AE::cv;
-	push @cbq, $cv;
-	#~ push @cbq, AE::cv->new;
+	push @cbq, AE::cv;
 	
 	bless ($self, $class);
-	say 'NEW' if DEBUG;
-	say Dumper $self if DEBUG;
+	say 'NEW '.Dumper($self) if DEBUG;
+	
 	return $self;
 }
 
@@ -85,8 +86,8 @@ Start and walk through the Callback Stack from step 0.
 sub start {
 	my $self = shift;
 	$step = 0;
-	say 'START' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
+	
+	say 'Start '.Dumper ($self, $step, @cbq) if DEBUG;
 	$self->step($step, @_);
 }
 
@@ -100,17 +101,11 @@ Add (append) callback into the Callback Stack.
 
 sub add {
 	my $self = shift;
-	say 'ADD - 1st' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
-	my $cv = AE::cv;
-	push @cbq, $cv;
-	#~ push @cbq, AE::cv->new;
-	say 'ADD' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
+	push @cbq, AE::cv;
+	
+	say 'ADD '.Dumper ($self, $step, @cbq) if DEBUG;
 	
 	$cbq[-2]->cb( shift );
-	say 'ADD - 2nd' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
 }
 
 =head2 next
@@ -127,11 +122,10 @@ Remember that only if you call this method, the next callback in stack will be t
 sub next {
 	my $self = shift;
 	$step++;
-	say "NEXT $step" if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
+	
+	say 'NEXT $step '.Dumper ($self, $step, @cbq) if DEBUG;
+	
 	$self->step($step, @_);
-	say 'NEXT' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
 }
 
 =head2 step
@@ -147,9 +141,10 @@ Start the callback flow from the specified step.
 sub step {
 	my $self = shift;
 	$step = shift;
+	
+	say 'STEP '.Dumper ($self, $step, @cbq) if DEBUG;
+	
 	$cbq[$step]->send( @_ );
-	say 'STEP' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
 }
 
 =head2 last
@@ -167,11 +162,42 @@ Usually it's called when you are writing a module and need to return it to your
 
 sub last {
 	my $self = shift;
-	say 'LAST' if DEBUG;
-	say Dumper ($self, $step, @cbq) if DEBUG;
+	
+	say 'LAST '.Dumper ($self, $step, @cbq) if DEBUG;
+	
 	return $cbq[-1];
 }
 
+
+=head1 SHORTCUT AE::CS API
+
+Inspired by AE.
+Starting with version 0.05, AnyEvent::CallbackStack officially supports a second, much
+simpler in name, API that is designed to reduce the typing.
+
+There is No Magic like what AE has on reducing calling and memory overhead.
+
+See the L<AE::CS> manpage for details.
+
+	my $cs = AE::CS;
+
+=cut
+
+package AE::CS;
+
+our $VERSION = $AnyEvent::CallbackStack::VERSION;
+
+sub _reset() {
+	eval q{ # poor man's autoloading {}
+		*AE::CS = sub {
+			AnyEvent::CallbackStack->new
+		};
+	};
+	die if $@;
+}
+BEGIN { _reset }
+
+
 =head1 AUTHOR
 
 BlueT - Matthew Lien - 練喆明, C<< <BlueT at BlueT.org> >>
